#
# spec file for package python-pyperclip
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyperclip
Version:        1.9.0
Release:        1.2
Summary:        A clipboard module for Python
License:        BSD-3-Clause
URL:            https://github.com/asweigart/pyperclip
Source0:        https://files.pythonhosted.org/packages/source/p/pyperclip/pyperclip-%{version}.tar.gz
# PATCH-FIX-UPSTREAM tests are broken with 1.9.0 release https://github.com/asweigart/pyperclip/issues/263
Patch:          tests.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       xclip
Requires:       xsel
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A clipboard module for Python. It only handles plain text.

%prep
%autosetup -p1 -n pyperclip-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/pyperclip
%{python_sitelib}/pyperclip-%{version}-py*.egg-info

%changelog
* Mon Oct 14 2024 Markéta Machová <mmachova@suse.com>
- Update to 1.9.0
  * Automatically cast the copy() argument to a string for all data types.
  * _py3_executable_exists and _py2_executable_exists had swapped names; fixed.
  * Pyperclip now "stringifies" all data types by passing it to str() (or
    globals()['__builtins__'].unicode on Python 2), so passing [1, 2, 3] would
    put '[1, 2, 3]' on the clipboard.
  * shutil.which() replaces the custom code (except in 2.7 and below which doesn't
    have shutil.which()).
  * Remove waitForPaste() and waitForNewPaste() functions, these aren't something
    the core library should have.
  * Reordered so that xclip is chosen before xsel since xclip is more popular.
- Add tests.patch to fix tests
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.8.2:
  + no changes available
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 1.8.1:
  + no changes available
* Wed Apr 29 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.8.0
  + no changes available
* Wed Mar 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 1.7.0
  * Added ability to read/write clipboard by running `python -m pyperclip`
- added sources
  https://github.com/asweigart/pyperclip/issues/17
  + LICENSE.txt
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Feb 13 2018 9+suse@cirno.systems
- Update to version 1.6.0
  * Capture stderr of xclip subprocess, fixed issue where emojii
    cut off the last character, allowed selection between PRIMARY
    and CLIPBOARD for xsel and xclip
  * Pyperclip works with qtpy module, set pyqt as lower priority
    than xsel/xclip/klipper, add support for PyQt5
  * Fixed the encoding that was set to "uft-8"
  * Added lazy loading
* Sat Mar 11 2017 jengelh@inai.de
- Trim redundant words from descriptions.
* Mon Mar  6 2017 aloisio@gmx.com
- Update to version 1.5.27
  * Disable broken cygwin implementation until issue 55 can be
    fixed
  * Fix #51, Replace wcscpy_s with memmove for Windows XP.
  * Fix #53, PEP8 changes, STRING_FUNCTION rename
- Converted to single-spec
- Updated source URL, license and homepage
* Sun Jan  3 2016 freitag@opensuse.org
- Update to upstream version 1.5.24
* Mon Aug 24 2015 freitag@opensuse.org
- First initial package of version 1.5.11
